@@ -32,7 +32,7 @@
   @author David Jarvie \<software@astrojar.org.uk\>
  */
 
-/**
+/*
 
 TODO: KDE5:
 
@@ -59,7 +59,8 @@ This API needs serious cleaning up:
 #include <QDateTime>
 #include <QTimeZone>
 
-namespace KCalCore
+/** Namespace for all KCalendarCore types. */
+namespace KCalendarCore
 {
 
 class CalFilter;
@@ -132,7 +133,8 @@ class KCALCORE_EXPORT Calendar : public QObject, public CustomProperties,
     public IncidenceBase::IncidenceObserver
 {
     Q_OBJECT
-    Q_PROPERTY(QString productId READ productId WRITE setProductId)
+    Q_PROPERTY(QString productId READ productId WRITE setProductId) //clazy:exclude=qproperty-without-notify
+    Q_PROPERTY(KCalendarCore::Person owner READ owner WRITE setOwner)
 
 public:
 
@@ -192,7 +194,7 @@ public:
 
       @see owner()
     */
-    void setOwner(const Person::Ptr &owner);
+    void setOwner(const Person &owner);
 
     /**
       Returns the owner of the calendar.
@@ -201,7 +203,7 @@ public:
 
       @see setOwner()
     */
-    Q_REQUIRED_RESULT Person::Ptr owner() const;
+    Q_REQUIRED_RESULT Person owner() const;
 
     /**
       Sets the default time specification zone used for creating
@@ -254,8 +256,6 @@ public:
 
       @param oldZone the time zone which provides the clock times
       @param newZone the new time zone
-
-      @see isLocalTime()
     */
     void shiftTimes(const QTimeZone &oldZone, const QTimeZone &newZone);
 
@@ -624,7 +624,7 @@ public:
 
       @return true if the Event was successfully remove; false otherwise.
 
-      @see addEvent(), deleteAllEvents()
+      @see addEvent()
     */
     virtual bool deleteEvent(const Event::Ptr &event) = 0;
 
@@ -838,7 +838,7 @@ public:
 
       @return true if the Todo was successfully removed; false otherwise.
 
-      @see addTodo(), deleteAllTodos()
+      @see addTodo()
     */
     virtual bool deleteTodo(const Todo::Ptr &todo) = 0;
 
@@ -1013,7 +1013,7 @@ public:
 
       @return true if the Journal was successfully removed; false otherwise.
 
-      @see addJournal(), deleteAllJournals()
+      @see addJournal()
     */
     virtual bool deleteJournal(const Journal::Ptr &journal) = 0;
 
@@ -1245,14 +1245,6 @@ public:
         */
         virtual void calendarIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence);
 
-        /**
-          Notify the Observer that an Incidence has been removed.
-          @param incidence is a pointer to the Incidence that was removed.
-          @deprecated this was called in between the deletion process, so the event it self it removed already,
-                      but the child events are not deleted. Better use AboutToBeDeleted or Deleted (with calendar argument) function to clearifiy.
-        */
-        KCALCORE_DEPRECATED virtual void calendarIncidenceDeleted(const Incidence::Ptr &incidence);
-
         /**
           Notify the Observer that an Incidence has been removed.
           @param incidence is a pointer to the Incidence that was removed.
@@ -1324,14 +1316,6 @@ protected:
     */
     void notifyIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence);
 
-    /**
-      Let Calendar subclasses notify that they removed an Incidence.
-      @param incidence is a pointer to the Incidence object that has been removed.
-      @deprecated this signal was sent in between the deletion, so the event it self is deleted but not there exceptions.
-                  better use either AboutToBeDeleted or the Deleted signal in future implementations.
-    */
-    KCALCORE_DEPRECATED void notifyIncidenceDeletedOld(const Incidence::Ptr &incidence);
-
     /**
       Let Calendar subclasses notify that they removed an Incidence.
       @param incidence is a pointer to the Incidence object that has been removed.
