@@ -34,13 +34,14 @@
 #include "kcalcore_export.h"
 #include "duration.h"
 
-#include <KDateTime>
-
+#include <QDateTime>
 #include <QDataStream>
 #include <QMetaType>
 #include <QVector>
 
-namespace KCalCore
+class QTimeZone;
+
+namespace KCalendarCore
 {
 
 /**
@@ -66,7 +67,7 @@ public:
       @param start the time the period begins.
       @param end the time the period ends.
     */
-    Period(const KDateTime &start, const KDateTime &end);
+    Period(const QDateTime &start, const QDateTime &end);
 
     /**
       Constructs a period from @p start and lasting @p duration.
@@ -74,7 +75,7 @@ public:
       @param start the time when the period starts.
       @param duration how long the period lasts.
     */
-    Period(const KDateTime &start, const Duration &duration);
+    Period(const QDateTime &start, const Duration &duration);
 
     /**
       Constructs a period by copying another period object
@@ -139,12 +140,12 @@ public:
     /**
       Returns when this period starts.
     */
-    KDateTime start() const;
+    Q_REQUIRED_RESULT QDateTime start() const;
 
     /**
       Returns when this period ends.
     */
-    KDateTime end() const;
+    Q_REQUIRED_RESULT QDateTime end() const;
 
     /**
       Returns the duration of the period.
@@ -158,7 +159,7 @@ public:
       If the period is defined in terms of a duration, that duration is
       returned unchanged.
     */
-    Duration duration() const;
+    Q_REQUIRED_RESULT Duration duration() const;
 
     /**
       Returns the duration of the period.
@@ -171,13 +172,13 @@ public:
 
       @param type the unit of time to use (seconds or days)
     */
-    Duration duration(Duration::Type type) const;
+    Q_REQUIRED_RESULT Duration duration(Duration::Type type) const;
 
     /**
       Returns true if this period has a set duration, false
       if it just has a start and an end.
     */
-    bool hasDuration() const;
+    Q_REQUIRED_RESULT bool hasDuration() const;
 
     /**
       Shift the times of the period so that they appear at the same clock
@@ -190,11 +191,10 @@ public:
       shifted from 14:00 (which is the London time of the period start) to
       14:00 Paris time.
 
-      @param oldSpec the time specification which provides the clock times
-      @param newSpec the new time specification
+      @param oldZone the time zone which provides the clock times
+      @param newZone the new time zone
     */
-    void shiftTimes(const KDateTime::Spec &oldSpec,
-                    const KDateTime::Spec &newSpec);
+    void shiftTimes(const QTimeZone &oldZone, const QTimeZone &newZone);
 
 private:
     //@cond PRIVATE
@@ -203,28 +203,28 @@ private:
     //@endcond
 
     friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream,
-            const KCalCore::Period &period);
+            const KCalendarCore::Period &period);
 
     friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream,
-            KCalCore::Period &period);
+            KCalendarCore::Period &period);
 };
 
 /** Write @p period to the datastream @p stream, in binary format. */
-KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KCalCore::Period &period);
+KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KCalendarCore::Period &period);
 
 /** Read a Period object into @p period from @p stream, in binary format. */
-KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalCore::Period &period);
+KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalendarCore::Period &period);
 
 /**
   Return a hash value for a Period argument.
   @param key is a Period.
 */
-KCALCORE_EXPORT uint qHash(const KCalCore::Period &key);
+KCALCORE_EXPORT uint qHash(const KCalendarCore::Period &key);
 }
 
 //@cond PRIVATE
-Q_DECLARE_METATYPE(KCalCore::Period)
-Q_DECLARE_TYPEINFO(KCalCore::Period, Q_MOVABLE_TYPE);
+Q_DECLARE_METATYPE(KCalendarCore::Period)
+Q_DECLARE_TYPEINFO(KCalendarCore::Period, Q_MOVABLE_TYPE);
 //@endcond
 
 #endif
