@@ -25,18 +25,17 @@
 #define KCALCORE_RECURRENCERULE_H
 
 #include "kcalcore_export.h"
-#include "sortablelist.h"
 
 #include <QDateTime>
 #include <QTimeZone>
 
 class QTimeZone;
 
-namespace KCalCore {
+namespace KCalendarCore {
 // These two are duplicates wrt. incidencebase.h
-typedef SortableList<QDate> DateList;
+typedef QList<QDate> DateList;
 /* List of times */
-typedef SortableList<QTime> TimeList;
+typedef QList<QTime> TimeList;
 
 /**
   This class represents a recurrence rule for a calendar incidence.
@@ -83,8 +82,8 @@ public:
         int mPos;   // week of the day (-1 for last, 1 for first, 0 for all weeks)
         // Bounded by -366 and +366, 0 means all weeks in that period
 
-        friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::RecurrenceRule::WDayPos &);
-        friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalCore::RecurrenceRule::WDayPos &);
+        friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalendarCore::RecurrenceRule::WDayPos &);
+        friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalendarCore::RecurrenceRule::WDayPos &);
     };
 
     RecurrenceRule();
@@ -246,7 +245,7 @@ public:
      * @param end inclusive end of interval
      * @return list of date/time values
      */
-    Q_REQUIRED_RESULT SortableList<QDateTime> timesInInterval(const QDateTime &start, const QDateTime &end) const;
+    Q_REQUIRED_RESULT QList<QDateTime> timesInInterval(const QDateTime &start, const QDateTime &end) const;
 
     /** Returns the date and time of the next recurrence, after the specified date/time.
      * If the recurrence has no time, the next date after the specified date is returned.
@@ -326,25 +325,25 @@ private:
     Private *const d;
     //@endcond
 
-    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::RecurrenceRule *);
-    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalCore::RecurrenceRule *);
+    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalendarCore::RecurrenceRule *);
+    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalendarCore::RecurrenceRule *);
 };
 
 /**
  * RecurrenceRule serializer and deserializer.
  * @since 4.12
  */
-KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::RecurrenceRule *);
-KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalCore::RecurrenceRule *);
+KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalendarCore::RecurrenceRule *);
+KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalendarCore::RecurrenceRule *);
 
 /**
  * RecurrenceRule::WDayPos serializer and deserializer.
  * @since 4.12
  */
-KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::RecurrenceRule::WDayPos &);
-KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalCore::RecurrenceRule::WDayPos &);
+KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalendarCore::RecurrenceRule::WDayPos &);
+KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalendarCore::RecurrenceRule::WDayPos &);
 }
 
-Q_DECLARE_TYPEINFO(KCalCore::RecurrenceRule::WDayPos, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KCalendarCore::RecurrenceRule::WDayPos, Q_MOVABLE_TYPE);
 
 #endif
